@@ -35,10 +35,13 @@ class MensajeRespuesta(object):
         body_element = root_element.find(
             '{http://schemas.xmlsoap.org/soap/envelope/}Body',
         )
-        return cls(
-            mensaje=body_element.find('mensajeRespuestaCDA'),
+
+        respuesta_element = body_element.find(
+            '{http://cep.fyg.com/}respuestaCDA',
         )
 
+        return etree.fromstring(respuesta_element.text)  # noqa: S320
+
 
 class Acuse(BaseModel):
     cda_id: str
