@@ -5,7 +5,10 @@ from spei.resources import Acuse
 
 class MensajeElement(object):
     def __new__(cls, body):
-        return body.find('mensajeRespuestaCDA')
+        mensaje = body.find(
+            '{http://cep.fyg.com/}respuestaCDA',
+        )
+        return etree.fromstring(mensaje.text)  # noqa: S320
 
 
 class BodyElement(object):
